==> haskell-generic-data-1.1.0.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.0
visibility:           public
id:                   generic-data-1.1.0.0-DUyMWUrBICaw3Alr8XqqT
key:                  generic-data-1.1.0.0-DUyMWUrBICaw3Alr8XqqT
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  b683f984e16bfd6f5260fe85e5f93cbe
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.0-DUyMWUrBICaw3Alr8XqqT
depends:
    ap-normalize-0.1.0.1-9HQrlDTZ9EHGRh8QCN8Gop base-4.17.2.1
    base-orphans-0.9.1-2hOCfn2j6E6Chy4Kfvc1ON
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-data-1.1.0.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.0
visibility:           public
id:                   generic-data-1.1.0.0-4ZAjJXhCSBwHgSJh90CNJp
key:                  generic-data-1.1.0.0-4ZAjJXhCSBwHgSJh90CNJp
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  43ee2aa396dbe1711452c217dc1b43e1
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-data-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.0-4ZAjJXhCSBwHgSJh90CNJp
depends:
    ap-normalize-0.1.0.1-9HQrlDTZ9EHGRh8QCN8Gop base-4.17.2.1
    base-orphans-0.9.1-2hOCfn2j6E6Chy4Kfvc1ON
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-boot-th-9.4.8
    show-combinators-0.2.0.0-6ZAszFLrSaHXY65bXLH1d

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
